@@ -37,6 +37,8 @@ Implementation Notes
 
 """
 
+# pylint: disable=too-many-instance-attributes
+
 import displayio
 from adafruit_display_shapes.line import Line
 
@@ -88,6 +90,13 @@ class Sparkline(displayio.Group):
             max_size=self._max_items - 1, x=x, y=y
         )  # self is a group of lines
 
+    def clear_values(self):
+        """Removes all values from the _spark_list list and removes all lines in the group"""
+
+        for _ in range(len(self)):  # remove all items from the current group
+            self.pop()
+        self._spark_list = []  # empty the list
+
     def add_value(self, value):
         """Add a value to the sparkline.
         :param value: The value to be added to the sparkline
